@@ -16,15 +16,15 @@ import ton.tonlibjson
 from .utils import *
 
 
-async def _get_client(ls: int):
+async def _get_client(ls: int, timeout: int):
     TonlibClient.enable_unaudited_binaries()
-    client = TonlibClient(ls_index=ls)
+    client = TonlibClient(ls_index=ls, default_timeout=timeout)
     await client.init_tonlib()
     return client
 
 
-def get_client(ls: int = 0) -> TonlibClient:
-    client = asyncio.get_event_loop().run_until_complete(_get_client(ls))
+def get_client(ls: int = 0, timeout: int = 30) -> TonlibClient:
+    client = asyncio.get_event_loop().run_until_complete(_get_client(ls, timeout))
     return client
 
 
@@ -52,7 +52,7 @@ async def _get_nft_owner(client: TonlibClient, addr: str):
     return owner_address
 
 
-def get_items(addresses: list, filename_with_nft_metadata = None, client: TonlibClient = None, max_requests: int = 1000, ls: int = 0):
+def get_items(addresses: list, filename_with_nft_metadata=None, client: TonlibClient = None, max_requests: int = 1000, ls: int = 0):
     items = {}
     if filename_with_nft_metadata and 'json' not in filename_with_nft_metadata:
         raise Exception('Only .json files are expected')
@@ -159,6 +159,8 @@ def get_all_wallet_transactions_raw(addr: str, limit: int = 10**9, client: Tonli
 
 def get_all_wallet_transactions(addr: str, limit: int = 10**9, client: TonlibClient = None):
     """
+    ! dont use with highload wallets !
+
     highly recommend to use with client which ls index = 2, for e.g. client = get_client(ls=2)
     """
     if not client:
@@ -215,6 +217,8 @@ async def _get_all_wallet_transactions_raw(client: TonlibClient, addr: str, limi
 
 def get_nft_items_by_owner_address(addr: str, client: TonlibClient = None):
     """
+    ! shows only nft items were bought by user or were transferred to user's wallet !
+
     highly recommend to use with client which ls index = 2, for e.g. client = get_client(ls=2)
     """
     if not client:
@@ -226,7 +230,7 @@ async def _get_nft_items_by_owner_address(client: TonlibClient, addr: str):
     result = set()
     all_transactions = await _get_all_wallet_transactions(client, addr)
     await client.tonlib_wrapper.close()
-    client = await _get_client(client.ls_index)
+    client = await _get_client(client.ls_index, timeout=15)
 
     async def proc_tr(tr):
         if tr['type'] == 'in':
@@ -261,7 +265,7 @@ async def _get_collection_items(client: TonlibClient, addr: str):
     async def get_item_addr(index, result):
         item = await account.get_nft_address_by_index(index=index)
         # result.append(item['address'].to_string(True, True, True)) # human-readable bounceable form
-        result.append(item['address'].to_string()) # raw form
+        result.append(item['address'].to_string(is_user_friendly=False)) # raw form
 
     result = []
 
@@ -269,7 +273,7 @@ async def _get_collection_items(client: TonlibClient, addr: str):
         await asyncio.gather(*[get_item_addr(i, result) for i in range(p * 10000, min(items_amount, 10000 * (p + 1)))])
     await client.tonlib_wrapper.close()
     if len(result) < items_amount:
-        raise Exception('GOT NOT ALL ITEMS')
+        raise Exception(f'GOT NOT ALL ITEMS.')
     return result
 
 
